@@ -97,6 +97,7 @@ class clientIF(object):
         self._broker_client = None
         self._subscriptions = defaultdict(list)
         self._scheduler = scheduler
+        self._unknown_vm_ids = set()
         if _glusterEnabled:
             self.gluster = gapi.GlusterApi()
         else:
@@ -146,6 +147,21 @@ class clientIF(object):
         with self.vmContainerLock:
             return self.vmContainer.copy()
 
+    def get_unknown_vm_ids(self):
+        """
+        Return iterable of unknown VM ids that were spotted.
+
+        This is intended to serve for detection of external VMs.
+        """
+        unknown_vm_ids = []
+        with self.vmContainerLock:
+            for vm_id in self._unknown_vm_ids.copy():
+                if vm_id in self.vmContainer:
+                    self._unknown_vm_ids.remove(vm_id)
+                else:
+                    unknown_vm_ids.append(vm_id)
+        return unknown_vm_ids
+
     @property
     def ready(self):
         return (self.irs is None or self.irs.ready) and not self._recovery
@@ -288,6 +304,29 @@ class clientIF(object):
 
         self.mom = MomClient(momconf)
 
+    def _wait_for_shutting_down_vms(self):
+        """
+        Wait loop checking remaining VMs in vm container
+
+        This method is helper method that highers the
+        probability of engine to properly acknowledge
+        that all VMs are terminated by host shutdown.
+
+        The VMs are shutdown by external service: libvirt-guests
+        The service pauses system shutdown on systemd shutdown
+        and gracefully shutdowns the running VMs.
+        """
+        # how long to wait before release shutdown
+        # we are waiting in whole seconds
+        # if config is not present, do not wait
+        timeout = config.getint('vars', 'timeout_engine_clear_vms')
+
+        for _ in range(timeout * 10):
+            if not self.vmContainer:
+                # once all VMs are cleared exit
+                break
+            time.sleep(0.1)
+
     def prepareForShutdown(self):
         """
         Prepare server for shutdown.
@@ -302,6 +341,8 @@ class clientIF(object):
                 self.log.debug('cannot run prepareForShutdown twice')
                 return errCode['unavail']
 
+            self._wait_for_shutting_down_vms()
+
             self._acceptor.stop()
             for binding in self.servers.values():
                 binding.stop()
@@ -500,8 +541,6 @@ class clientIF(object):
             # recover stage 3: waiting for domains to go up
             self._waitForDomainsUp()
 
-            recovery.clean_vm_files(self)
-
             self._recovery = False
 
             # Now if we have VMs to restore we should wait pool connection
@@ -528,6 +567,7 @@ class clientIF(object):
             if not v:
                 self.log.debug('unknown vm %s event %s args %s',
                                vmid, events.event_name(eventid), args)
+                self._unknown_vm_ids.add(vmid)
                 return
 
             if eventid == libvirt.VIR_DOMAIN_EVENT_ID_LIFECYCLE:
