@@ -20,18 +20,15 @@
 
 from __future__ import absolute_import
 import logging
-import os
 import errno
 import six
 
-from vdsm.network import netinfo
 from vdsm.network.ip.address import ipv6_supported
 from vdsm.network.ip import dhclient
 from vdsm.network.ipwrapper import getLinks
 from vdsm.network.link import dpdk
-from vdsm.network.link.iface import get_mtu
+from vdsm.network.link import iface as link_iface
 from vdsm.network.netconfpersistence import RunningConfig
-from vdsm.network.netlink import link as nl_link
 
 from .addresses import getIpAddrs, getIpInfo, is_ipv6_local_auto
 from . import bonding
@@ -160,8 +157,10 @@ def networks_base_info(running_nets, routes=None, ipaddrs=None):
 
     info = {}
     for net, attrs in six.viewitems(running_nets):
+        iface = get_net_iface_from_config(net, attrs)
         try:
-            iface = get_net_iface_from_config(net, attrs)
+            if not link_iface.iface(iface).exists():
+                raise NetworkIsMissing('Iface %s was not found' % iface)
             info[net] = _getNetInfo(iface, attrs['bridged'], routes, ipaddrs)
         except NetworkIsMissing:
             # Missing networks are ignored, reporting only what exists.
@@ -211,25 +210,9 @@ def _devinfo(link, routes, ipaddrs):
             'ipv4defaultroute': is_default_route(gateway)}
 
 
-def ifaceUsed(iface):
-    """Lightweight implementation of bool(Netinfo.ifaceUsers()) that does not
-    require a NetInfo object."""
-    if os.path.exists(os.path.join(netinfo.NET_PATH, iface, 'brport')):
-        return True  # Is it a port
-    for linkDict in nl_link.iter_links():
-        if linkDict['name'] == iface and 'master' in linkDict:  # Is it a slave
-            return True
-        if linkDict.get('device') == iface and linkDict.get('type') == 'vlan':
-            return True  # it backs a VLAN
-    for net_name, net_attr in six.viewitems(RunningConfig().networks):
-        if get_net_iface_from_config(net_name, net_attr) == iface:
-            return True
-    return False
-
-
 def _getNetInfo(iface, bridged, routes, ipaddrs):
     """Returns a dictionary of properties about the network's interface status.
-    Raises a KeyError if the iface does not exist."""
+    Raises a NetworkIsMissing if the iface does not exist."""
     data = {}
     try:
         if bridged:
@@ -253,7 +236,7 @@ def _getNetInfo(iface, bridged, routes, ipaddrs):
                      'gateway': gateway,
                      'ipv6gateway': get_gateway(routes, iface, family=6),
                      'ipv4defaultroute': is_default_route(gateway),
-                     'mtu': get_mtu(iface)})
+                     'mtu': link_iface.iface(iface).mtu()})
     except (IOError, OSError) as e:
         if e.errno == errno.ENOENT or e.errno == errno.ENODEV:
             logging.info('Obtaining info for net %s.', iface, exc_info=True)
