@@ -1,5 +1,5 @@
 #
-# Copyright 2008-2016 Red Hat, Inc.
+# Copyright 2008-2017 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,13 +25,13 @@ import logging
 import six
 
 from vdsm import metrics
+from vdsm.common.time import monotonic_time
 from vdsm.utils import convertToStr
 
-from vdsm.utils import monotonic_time
 from vdsm.virt.utils import isVdsmImage
 
 
-_MBPS_TO_BPS = 10 ** 6 / 8
+_log = logging.getLogger('virt.vmstats')
 
 
 def produce(vm, first_sample, last_sample, interval):
@@ -89,11 +89,12 @@ def tune_io(vm, stats):
     io_tune_info = []
 
     for disk in vm.getDiskDevices():
-        if "ioTune" in disk.specParams:
+        iotune = disk.iotune
+        if iotune:
             io_tune_info.append({
                 "name": disk.name,
                 "path": disk.path,
-                "ioTune": disk.specParams["ioTune"]
+                "ioTune": iotune
             })
 
     stats['ioTune'] = io_tune_info
@@ -118,7 +119,7 @@ def cpu(stats, first_sample, last_sample, interval):
     if first_sample is None or last_sample is None:
         return None
     if interval <= 0:
-        logging.warning(
+        _log.warning(
             'invalid interval %i when computing CPU stats',
             interval)
         return None
@@ -148,21 +149,15 @@ def cpu(stats, first_sample, last_sample, interval):
 
 
 def balloon(vm, stats, sample):
-    max_mem = int(vm.conf.get('memSize')) * 1024
-
-    for dev in vm.getBalloonDevicesConf():
-        if dev['specParams']['model'] != 'none':
-            balloon_target = dev.get('target', max_mem)
-            break
-    else:
-        balloon_target = None
+    max_mem = vm.mem_size_mb() * 1024
+    balloon_info = vm.get_balloon_info()
 
     stats['balloonInfo'] = {}
 
     # Do not return any balloon status info before we get all data
     # MOM will ignore VMs with missing balloon information instead
     # using incomplete data and computing wrong balloon targets
-    if balloon_target is not None and sample is not None:
+    if balloon_info['target'] is not None and sample is not None:
 
         balloon_cur = 0
         with _skip_if_missing_stats(vm):
@@ -170,10 +165,9 @@ def balloon(vm, stats, sample):
 
         stats['balloonInfo'].update({
             'balloon_max': str(max_mem),
-            'balloon_min': str(
-                int(vm.conf.get('memGuaranteedSize', '0')) * 1024),
+            'balloon_min': str(balloon_info['minimum']),
             'balloon_cur': str(balloon_cur),
-            'balloon_target': str(balloon_target)
+            'balloon_target': str(balloon_info['target'])
         })
 
 
@@ -187,7 +181,7 @@ def cpu_count(stats, sample):
         if vcpu_count != -1:
             stats['vcpuCount'] = vcpu_count
         else:
-            logging.error('Failed to get VM cpu count')
+            _log.error('Failed to get VM cpu count')
 
 
 def send_metrics(vms_stats):
@@ -255,18 +249,18 @@ def send_metrics(vms_stats):
 
         # Guest cpu-count,apps list, status, mac addr, client IP,
         # display type, kvm enabled, username, vcpu info, vm jobs,
-        # displayinfo, hash, acpi, fqdn, vm uuid, pid, vNodeRuntimeInfo,
+        # displayinfo, hash, acpi, fqdn, vm uuid, pid,
         #
         # are all meta-data that should be published separately
 
         metrics.send(data)
     except KeyError:
-        logging.exception('VM metrics collection failed')
+        _log.exception('VM metrics collection failed')
 
 
-def _nic_traffic(vm_obj, name, model, mac,
+def _nic_traffic(vm_obj, nic,
                  start_sample, start_index,
-                 end_sample, end_index, interval):
+                 end_sample, end_index):
     """
     Return per-nic statistics packed into a dictionary
     - macAddr
@@ -284,7 +278,6 @@ def _nic_traffic(vm_obj, name, model, mac,
     Expects the indexes of the nic whose statistics needs to be produced,
     for each sampling:
     `start_index' for `start_sample', `end_index' for `end_sample'.
-    `interval' is the time between the two samplings, in seconds.
     `vm_obj' is the Vm instance to which the nic belongs.
     `name', `model' and `mac' are the attributes of the said nic.
     Those three value are reported in the output stats.
@@ -292,14 +285,7 @@ def _nic_traffic(vm_obj, name, model, mac,
     Return the `stats' dictionary on success.
     """
 
-    if_speed = 1000 if model in ('e1000', 'virtio') else 100
-
-    if_stats = {
-        'macAddr': mac,
-        'name': name,
-        'speed': str(if_speed),
-        'state': 'unknown',
-    }
+    if_stats = nic_info(nic)
 
     with _skip_if_missing_stats(vm_obj):
         if_stats['rxErrors'] = str(end_sample['net.%d.rx.errs' % end_index])
@@ -322,7 +308,7 @@ def networks(vm, stats, first_sample, last_sample, interval):
     if first_sample is None or last_sample is None:
         return None
     if interval <= 0:
-        logging.warning(
+        _log.warning(
             'invalid interval %i when computing network stats for vm %s',
             interval, vm.id)
         return None
@@ -339,14 +325,25 @@ def networks(vm, stats, first_sample, last_sample, interval):
             continue
 
         stats['network'][nic.name] = _nic_traffic(
-            vm, nic.name, nic.nicModel, nic.macAddr,
+            vm, nic,
             first_sample, first_indexes[nic.name],
-            last_sample, last_indexes[nic.name],
-            interval)
+            last_sample, last_indexes[nic.name])
 
     return stats
 
 
+def nic_info(nic):
+    info = {
+        'macAddr': nic.macAddr,
+        'name': nic.name,
+        'speed': str(
+            1000 if nic.nicModel in ('e1000', 'virtio') else 100
+        ),
+        'state': 'unknown',
+    }
+    return info
+
+
 def disks(vm, stats, first_sample, last_sample, interval):
     if first_sample is None or last_sample is None:
         return None
@@ -362,23 +359,13 @@ def disks(vm, stats, first_sample, last_sample, interval):
     for vm_drive in vm.getDiskDevices():
         drive_stats = {}
         try:
-            drive_stats = {
-                'truesize': str(vm_drive.truesize),
-                'apparentsize': str(vm_drive.apparentsize),
-                'readLatency': '0',
-                'writeLatency': '0',
-                'flushLatency': '0'
-            }
-            if isVdsmImage(vm_drive):
-                drive_stats['imageID'] = vm_drive.imageID
-            elif "GUID" in vm_drive:
-                drive_stats['lunGUID'] = vm_drive.GUID
+            drive_stats = disk_info(vm_drive)
 
             if (vm_drive.name in first_indexes and
                vm_drive.name in last_indexes):
                 # will be None if sampled during recovery
                 if interval <= 0:
-                    logging.warning(
+                    _log.warning(
                         'invalid interval %i when calculating '
                         'stats for vm %s disk %s',
                         interval, vm.id, vm_drive.name)
@@ -398,8 +385,8 @@ def disks(vm, stats, first_sample, last_sample, interval):
                         last_sample, last_indexes[vm_drive.name]))
 
         except AttributeError:
-            logging.exception("Disk %s stats not available",
-                              vm_drive.name)
+            _log.exception("Disk %s stats not available",
+                           vm_drive.name)
 
         disk_stats[vm_drive.name] = drive_stats
 
@@ -409,6 +396,21 @@ def disks(vm, stats, first_sample, last_sample, interval):
     return stats
 
 
+def disk_info(vm_drive):
+    drive_stats = {
+        'truesize': str(vm_drive.truesize),
+        'apparentsize': str(vm_drive.apparentsize),
+        'readLatency': '0',
+        'writeLatency': '0',
+        'flushLatency': '0'
+    }
+    if isVdsmImage(vm_drive):
+        drive_stats['imageID'] = vm_drive.imageID
+    elif "GUID" in vm_drive:
+        drive_stats['lunGUID'] = vm_drive.GUID
+    return drive_stats
+
+
 def _disk_rate(first_sample, first_index, last_sample, last_index, interval):
     stats = {}
 
@@ -495,10 +497,10 @@ def _skip_if_missing_stats(vm_obj):
     """
     try:
         yield
-    except KeyError:
+    except KeyError as exc:
         if not vm_obj.monitorable:
             # If a VM is migration destination,
             # libvirt doesn't give any disk stat.
             pass
         else:
-            raise
+            _log.warning('Missing stat: %s for vm %s', str(exc), vm_obj.id)
