@@ -1,5 +1,5 @@
 #
-# Copyright 2012-2016 Red Hat, Inc.
+# Copyright 2012-2017 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -35,7 +35,7 @@ from testlib import temporaryPath
 import verify
 
 from vdsm import cpuarch
-from vdsm.utils import CommandPath
+from vdsm.common.cmdutils import CommandPath
 from vdsm.virt import vmstatus
 from vdsm.storage.misc import execCmd
 
@@ -195,7 +195,7 @@ class VirtTestBase(TestCaseBase, verify.DeviceMixin):
         if targetUptime > 0:
             self.assertTrue(int(result['elapsedTime']) >= targetUptime)
         else:
-            self.assertEquals(result['status'], vmstatus.UP)
+            self.assertEqual(result['status'], vmstatus.UP)
 
     def _waitForBoot(self, vmid):
         self.retryAssert(partial(self.assertQemuSetupComplete, vmid),
@@ -228,6 +228,7 @@ class VirtTest(VirtTestBase):
     def testSimpleVm(self):
         customization = {'vmId': '77777777-ffff-3333-bbbb-222222222222',
                          'vmName': 'testSimpleVm',
+                         'devices': [],
                          'display': _GRAPHICS_FOR_ARCH[platform.machine()]}
 
         with RunningVm(self.vdsm, customization) as vm:
@@ -278,7 +279,8 @@ class VirtTest(VirtTestBase):
     @requireKVM
     def testHeadlessVm(self):
         customization = {'vmId': '77777777-ffff-3333-bbbb-222222222222',
-                         'vmName': 'testHeadlessVm'}
+                         'vmName': 'testHeadlessVm',
+                         'devices': []}
 
         with RunningVm(self.vdsm, customization) as vm:
             self._waitForStartup(vm, VM_MINIMAL_UPTIME)
@@ -433,6 +435,7 @@ class VirtTest(VirtTestBase):
     def testVmWithSla(self):
         customization = {'vmId': '99999999-aaaa-ffff-bbbb-111111111111',
                          'vmName': 'testVmWithSla',
+                         'devices': [],
                          'display': _GRAPHICS_FOR_ARCH[platform.machine()]}
 
         with RunningVm(self.vdsm, customization) as vm:
