@@ -22,7 +22,7 @@ from __future__ import absolute_import
 from nose.plugins.attrib import attr
 from nose.plugins.skip import SkipTest
 
-from vdsm.network.link import iface
+from vdsm.network.link.iface import iface
 from vdsm.network.lldpad import lldptool
 
 from testlib import VdsmTestCase, mock
@@ -34,12 +34,6 @@ from .nettestlib import requires_systemctl
 
 LLDP_CHASSIS_ID_TLV = 'Chassis ID TLV\n\tMAC: 01:23:45:67:89:ab'
 
-LLDP_MANAGEMENT_ADDRESS_TLV = """
-Management Address TLV
-\tIPv4: 10.35.23.241
-\tIfindex: 83886080
-"""
-
 LLDP_MULTIPLE_TLVS = """
 Chassis ID TLV
 \tMAC: 01:23:45:67:89:ab
@@ -119,25 +113,14 @@ class LldpadReportTests(VdsmTestCase):
         {'subtype': 3, 'oui': 32962, 'type': 127, 'name': 'VLAN Name',
          'properties': {'VLAN ID': 'Name bar', 'VLAN Name': '2001'}}]
 
-    @mock.patch.object(lldptool.commands, 'execCmd',
-                       lambda command, raw: (0, LLDP_CHASSIS_ID_TLV, ''))
+    @mock.patch.object(lldptool.cmd, 'exec_sync',
+                       lambda x: (0, LLDP_CHASSIS_ID_TLV, ''))
     def test_get_single_lldp_tlv(self):
         expected = [self.TLVS_REPORT[0]]
         self.assertEqual(expected, lldptool.get_tlvs('iface0'))
 
-    @mock.patch.object(lldptool.commands, 'execCmd',
-                       lambda cmd, raw: (0, LLDP_MANAGEMENT_ADDRESS_TLV, ''))
-    def test_get_management_address_tlv_without_oid(self):
-        expected = [
-            {'type': 8, 'name': 'Management Address',
-             'properties': {'interface numbering subtype': 'Ifindex',
-                            'interface numbering': '83886080',
-                            'management address subtype': 'IPv4',
-                            'management address': '10.35.23.241'}}]
-        self.assertEqual(expected, lldptool.get_tlvs('iface0'))
-
-    @mock.patch.object(lldptool.commands, 'execCmd',
-                       lambda command, raw: (0, LLDP_MULTIPLE_TLVS, ''))
+    @mock.patch.object(lldptool.cmd, 'exec_sync',
+                       lambda x: (0, LLDP_MULTIPLE_TLVS, ''))
     def test_get_multiple_lldp_tlvs(self):
         self.assertEqual(self.TLVS_REPORT, lldptool.get_tlvs('iface0'))
 
@@ -152,8 +135,8 @@ class LldpadReportIntegTests(VdsmTestCase):
 
     def test_get_lldp_tlvs(self):
         with veth_pair() as (nic1, nic2):
-            iface.up(nic1)
-            iface.up(nic2)
+            iface(nic1).up()
+            iface(nic2).up()
             with enable_lldp_on_ifaces((nic1, nic2), rx_only=False):
                 self.assertTrue(lldptool.is_lldp_enabled_on_iface(nic1))
                 self.assertTrue(lldptool.is_lldp_enabled_on_iface(nic2))
