@@ -348,15 +348,15 @@ class FakeVM(object):
         finally:
             del self.conf['_migrationParams']
 
+    def min_cluster_version(self, major, minor):
+        return False
+
     def status(self):
         return self.conf
 
     def getStats(self):
         return {}
 
-    def saveState(self):
-        pass
-
     def setDownStatus(self, status, reason):
         pass
 
